"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved. Licensed under the MIT license.
// See LICENSE in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
exports.pitch = void 0;
const defaultThemedStylesPath = require.resolve('@microsoft/load-themed-styles');
/**
 * This simple loader wraps the loading of CSS in script equivalent to
 *  require("load-themed-styles").loadStyles('... css text ...').
 *
 * @public
 */
// eslint-disable-next-line func-style
const pitch = function (remainingRequest) {
    const loaderContext = this;
    const options = loaderContext.getOptions() || {};
    if (options.namedExport) {
        throw new Error('The "namedExport" option has been removed.');
    }
    const { async = false, loadThemedStylesPath = defaultThemedStylesPath, esModule = false } = options;
    const stringifiedRequest = JSON.stringify(loaderContext.utils.contextify(loaderContext.context, '!!' + remainingRequest));
    const importCode = esModule
        ? [
            `import content from ${stringifiedRequest};`,
            `import { loadStyles } from ${JSON.stringify(loadThemedStylesPath)};`
        ]
        : [
            `var content = require(${stringifiedRequest});`,
            `var loader = require(${JSON.stringify(loadThemedStylesPath)});`
        ];
    return [
        ...importCode,
        '',
        'if(typeof content === "string") content = [[module.id, content]];',
        '',
        '// add the styles to the DOM',
        `for (var i = 0; i < content.length; i++) ${esModule ? 'loadStyles' : 'loader.loadStyles'}(content[i][1], ${async === true});`,
        '',
        'if(content.locals) module.exports = content.locals;'
    ].join('\n');
};
exports.pitch = pitch;
//# sourceMappingURL=index.js.map